</div>
<!--===// Start: Cursor
	=================================-->
<div id="cursor">
	<div class="cursor__circle"></div>
</div>
 <!-- End: Cursor
=================================-->
<footer id="footer-section" class="footer-section st-py-default pb-0">
	
	<?php
	if( function_exists('cleverfox_activate')):
	
		$hotel26_above_footer_hs		= get_theme_mod('above_footer_hs', '1');
		if( $hotel26_above_footer_hs == '1' ) :
			get_template_part('template-parts/sections/section','service-three');
		endif;
	endif;
	?>
	
	<div class="container">
		<!-- footer content -->
		<div class="footer-content py-3 py-sm-4">
			<div class="row g-4">
			<?php if( function_exists('cleverfox_activate')) { ?>
				<div class="col-lg-4 col-xl-3 wow fadeIn" data-wow-delay="100ms" data-wow-duration="1500ms">
					<div class="guarantee-box">
						<div class="footer-award">
						<?php
							$hotel26_award2_contents			= get_theme_mod('award_two_contents',hotel26_award2_default());	
							
							if ( ! empty( $hotel26_award2_contents ) ) {
							$hotel26_award2_contents = json_decode( $hotel26_award2_contents );
							foreach ( $hotel26_award2_contents as $hotel26_index => $hotel26_award2_item ) {
								$hotel26_repeater_image = ! empty( $hotel26_award2_item->image_url ) ? apply_filters( 'hotel_26_translate_single_string', $hotel26_award2_item->image_url, 'Award 2 section' ) : ''; 
							if(!empty($hotel26_repeater_image)):
								echo '<div><img decoding="async" src="'.esc_url($hotel26_repeater_image).'" alt="'.esc_attr__('Award','hotel-26').'"></div>';
							endif;
							}}	
						?>
						</div>
						<?php $hotel26_footer_widget_left_img	=	get_theme_mod('footer_widget_left_img', get_template_directory_uri(). '/assets/images/footer/our-guarantee.png'); ?>
						<div class="guarantee-title"><img decoding="async" src="<?php echo esc_url($hotel26_footer_widget_left_img); ?>" alt="<?php echo esc_attr__('guarantee','hotel-26'); ?>"></div>
						<ul class="guarantee-list">
						<?php
							$hotel26_trust_list_contents			= get_theme_mod('trust_list_contents',hotel26_trust_default());	
							
							if ( ! empty( $hotel26_trust_list_contents ) ) {
							$allowed_html = array('span' => array());
							$hotel26_trust_list_contents = json_decode( $hotel26_trust_list_contents );
							foreach ( $hotel26_trust_list_contents as $hotel26_index => $hotel26_trust_list_item ) {
								$hotel26_repeater_title = ! empty( $hotel26_trust_list_item->title ) ? apply_filters( 'hotel_26_translate_single_string', $hotel26_trust_list_item->title, 'Award 2 section' ) : ''; 
								$hotel26_repeater_icon = ! empty( $hotel26_trust_list_item->icon_value ) ? apply_filters( 'hotel_26_translate_single_string', $hotel26_trust_list_item->icon_value, 'Award 2 section' ) : ''; 
							if(!empty($hotel26_repeater_icon)):
								echo '<li><div class="icon-circle"><i class="fa '.esc_attr($hotel26_repeater_icon).'"></i></div>
								<div class="guarantee-text">'.wp_kses( html_entity_decode($hotel26_repeater_title),$allowed_html).'</div></li>';
							endif;
							}}	
						?>
						</ul>
					</div>
				</div>
			<?php } ?>
				<div class="col-lg-8 col-xl-9">
				<?php if( function_exists('cleverfox_activate')) { ?>
					<div class="footer-info-bar wow fadeIn" data-wow-delay="200ms" data-wow-duration="1500ms">
					<?php
						$hotel26_business_call_img			= get_theme_mod('business_call_img',get_template_directory_uri().'/assets/images/footer/call.png');
						$hotel26_business_call_ttl_one		= get_theme_mod('business_call_ttl_one');
						$hotel26_business_call_num_one		= get_theme_mod('business_call_num_one');
						$hotel26_business_call_ttl_two		= get_theme_mod('business_call_ttl_two');
						$hotel26_business_call_num_two		= get_theme_mod('business_call_num_two');
						
						$hotel26_business_location_img		= get_theme_mod('business_location_img', get_template_directory_uri().'/assets/images/footer/google.png');
						$hotel26_business_location_ttl		= get_theme_mod('business_location_ttl');
						$hotel26_business_location_subttl	= get_theme_mod('business_location_subttl');
						$hotel26_business_location_link		= get_theme_mod('business_location_link');
					?>
						<aside class="widget widget-contact">
							<h4 class="widget-title"></h4>
							<div class="contact-area d-flex align-items-center">
								<?php 
								if( !empty($hotel26_business_call_img)) { 
									echo '<div class="contact-icon"><img src="'.esc_url($hotel26_business_call_img).'" alt="'.esc_attr__('Business Call Image','hotel-26').'" /></div>';
								}
								
								if( !empty( $hotel26_business_call_ttl_one ) || !empty( $hotel26_business_call_num_one ) || !empty( $hotel26_business_call_ttl_two ) || !empty( $hotel26_business_call_num_two ) ) {
								echo '<div class="contact-info flex-grow-1">
									<p class="text">'.esc_html($hotel26_business_call_ttl_one).' : <a href="tel:'.esc_attr($hotel26_business_call_num_one).'">'.esc_html($hotel26_business_call_num_one).'</a></p>
									<p class="text">'.esc_html($hotel26_business_call_ttl_two).' : <a href="tel:'.esc_attr($hotel26_business_call_num_two).'">'.esc_html($hotel26_business_call_num_two).'</a></p>
								</div>';
								}
								?>
							</div>
						</aside>
						<aside class="widget widget-contact">
							<h4 class="widget-title"></h4>
							<div class="contact-area d-flex align-items-center">
							<?php 
								if( !empty($hotel26_business_location_img)) { 
									echo '<div class="contact-icon"><img src="'.esc_url($hotel26_business_location_img).'" alt="'.esc_attr__('Business Call Image','hotel-26').'" /></div>';
								}
								if( !empty( $hotel26_business_call_num_one ) || !empty( $hotel26_business_location_subttl ) ) {
								echo '<div class="contact-info flex-grow-1">
									<p class="text">'.esc_html($hotel26_business_location_ttl).'</p>
									<p class="text" ><a href="'.esc_url($hotel26_business_location_link).'" class="color-secondary">'.esc_html($hotel26_business_location_subttl).' <i class="fa fa-long-arrow-right"></i></a></p>
								</div>';
								}
							?>
							</div>
						</aside>
					</div>
					<?php } ?>
					<div class="row ps-lg-4 g-2 g-sm-4 wow fadeIn" data-wow-delay="200ms" data-wow-duration="1500ms">
						<?php hotel26_get_sidebars( 'hotel-26-footer-1' ); ?>
						<?php hotel26_get_sidebars( 'hotel-26-footer-2' ); ?>
						<?php hotel26_get_sidebars( 'hotel-26-footer-3' ); ?>
					</div>
				</div>
			</div>
		</div>
		<!-- Above -->
		<?php 
			$hotel26_below_footer_hs			= get_theme_mod('below_footer_hs','1');
			if( $hotel26_below_footer_hs == '1' ) {
		?>
		<?php if( function_exists('cleverfox_activate')) { ?>
		<div class="footer-above">
			<div class="row align-items-center">
				<div class="col-md-6 col-12 text-center text-md-start wow fadeIn" data-wow-delay="0ms" data-wow-duration="1500ms">
					<aside class="widget widget_social_widget">
						<h4 class="widget-title d-none"></h4>
						<ul>
						<?php
							$hotel26_social_icon_contents			= get_theme_mod('social_icon_contents',hotel26_social_icon_default());	
							
							if ( ! empty( $hotel26_social_icon_contents ) ) {
							$hotel26_social_icon_contents = json_decode( $hotel26_social_icon_contents );
							foreach ( $hotel26_social_icon_contents as $hotel26_index => $hotel26_social_icon_item ) {
								$hotel26_repeater_icon = ! empty( $hotel26_social_icon_item->icon_value ) ? apply_filters( 'hotel_26_translate_single_string', $hotel26_social_icon_item->icon_value, 'Social section' ) : ''; 
								$hotel26_repeater_link = ! empty( $hotel26_social_icon_item->image_link ) ? apply_filters( 'hotel_26_translate_single_string', $hotel26_social_icon_item->image_link, 'Social section' ) : ''; 
							if(!empty($hotel26_repeater_icon)):
								echo '<li><a href="'.esc_url($hotel26_repeater_link).'" target="_blank" rel="noreferrer noopener nofollow" class="social-a wow zoomIn"><i class="fab '.esc_attr($hotel26_repeater_icon).'"></i></a></li>';
							endif;
							}}	
						?>
						</ul>
					</aside>
				</div>
				<?php $hotel26_rtl = !is_rtl() ? 'end' : 'start'; ?>
				<div class="col-md-6 col-12 text-center text-md-<?php echo esc_attr($hotel26_rtl); ?> wow fadeIn" data-wow-delay="200ms" data-wow-duration="1500ms">
					<div class="widget-right">                          
						<ul class="payments">
						<?php
							$hotel26_payment_contents			= get_theme_mod('payment_contents',hotel26_payment_default());	
							
							if ( ! empty( $hotel26_payment_contents ) ) {
							$hotel26_payment_contents = json_decode( $hotel26_payment_contents );
							foreach ( $hotel26_payment_contents as $hotel26_index => $hotel26_payment_item ) {
								$hotel26_repeater_title = ! empty( $hotel26_payment_item->title ) ? apply_filters( 'hotel_26_translate_single_string', $hotel26_payment_item->title, 'Payment section' ) : ''; 
								$hotel26_repeater_image = ! empty( $hotel26_payment_item->image_url ) ? apply_filters( 'hotel_26_translate_single_string', $hotel26_payment_item->image_url, 'Payment section' ) : ''; 
								$hotel26_repeater_link = ! empty( $hotel26_payment_item->image_link ) ? apply_filters( 'hotel_26_translate_single_string', $hotel26_payment_item->image_link, 'Payment section' ) : ''; 
							if(!empty($hotel26_repeater_image)):
								echo '<li><a href="'.esc_url($hotel26_repeater_link).'" rel="nofollow"><img src="'.esc_url($hotel26_repeater_image).'" alt="'.esc_attr($hotel26_repeater_title).'"></a></li>';
							endif;
							}}	
						?>
						</ul>
					</div>
				</div>
			</div>
		</div>
		<?php }} ?>
	</div>

	<!-- copyright -->
	<?php
	 $hotel26_ltr = is_rtl() ? 'end' : 'start';
	 $hotel26_rtl = !is_rtl() ? 'end' : 'start';
?>
	<div class="footer-copyright">
		<div class="container">
			<div class="row align-items-center">
				<div class="col-md-6 col-12 text-center text-md-<?php echo esc_attr($hotel26_ltr); ?> wow fadeIn" data-wow-delay="0ms" data-wow-duration="1500ms">
					<div class="widget-left">
						<?php
						$footer_first_custom 		= get_theme_mod('footer_first_custom','Copyright © [current_year] [theme_author] All Rights Reserved');
						
							$hotel_26_copyright_allowed_tags = array(
								'[current_year]' => date_i18n('Y', current_time( 'timestamp' )),
								'[site_title]'   => get_bloginfo('name'),
								'[theme_author]' => sprintf(__('<a href="#">Nayra Hotel</a>', 'hotel-26')),
							);
						?>  
						<div class="widget textwidget">
							<div class="brand">                      
							<p class="copyright-text mb-0">
								<?php
									echo apply_filters('hotel_26_footer_copyright', wp_kses_post(hotel_26_str_replace_assoc($hotel_26_copyright_allowed_tags, $footer_first_custom)));
								?>
								</p>
							</div>
						 </div>
					</div>
				</div>
				<div class="col-md-6 col-12 text-center text-md-<?php echo esc_attr($hotel26_rtl); ?> wow fadeIn" data-wow-delay="200ms" data-wow-duration="1500ms">
					<div class="widget-right">
						<aside class="widget widget_nav_menu">
							<div class="menu-pages-container">
								<?php 
									wp_nav_menu( 
										array(  
											'theme_location' => 'footer_menu',
											'container'  => '',
											'menu_class' => 'menu',
											'fallback_cb' => 'WP_Bootstrap_Navwalker::fallback',
											'walker' => new WP_Bootstrap_Navwalker()
											 ) 
										);
								?>   
							</div>
						</aside>
					</div>
				</div>
			</div>
		</div>
	</div>
</footer>

<?php
	$hotel26_hs_mouse_cursor	=	get_theme_mod('hs_mouse_cursor','1');
	if( $hotel26_hs_mouse_cursor == '1' ) { ?>
		<div class="st-mouseCursor cursor-outer"></div>
		<div class="st-mouseCursor cursor-inner"></div>
<?php } ?>
<!--=========
Scroll up
===========-->
<button type="button" class="scrollup style-1"><i class="fa fa-arrow-up"></i></button>

<!--============
End: Scroll up
=============-->
<?php wp_footer(); ?>
